@@ -1,4 +1,6 @@
-from didiator.interface import Request
+from typing import Any
+
+from didiator.interface.entities import Command, Request, Query
 
 
 class MediatorError(Exception):
@@ -6,16 +8,16 @@ class MediatorError(Exception):
 
 
 class HandlerNotFound(MediatorError, TypeError):
-    request: Request
+    request: Request[Any]
 
-    def __init__(self, text: str, request: Request):
+    def __init__(self, text: str, request: Request[Any]):
         super().__init__(text)
         self.request = request
 
 
 class CommandHandlerNotFound(HandlerNotFound):
-    pass
+    request: Command[Any]
 
 
 class QueryHandlerNotFound(HandlerNotFound):
-    pass
+    request: Query[Any]
