@@ -1,5 +1,5 @@
 import abc
-from typing import Any, Awaitable, Callable, Generic, Type, TypeVar
+from typing import Any, Awaitable, Callable, Generic, Type, TypeVar, Union
 
 from didiator.interface.entities.request import Request
 
@@ -10,7 +10,7 @@ R = TypeVar("R", bound=Request[Any])
 class Handler(abc.ABC, Generic[R, RRes]):
     @abc.abstractmethod
     async def __call__(self, request: R) -> RRes:
-        ...
+        raise NotImplementedError
 
 
-HandlerType = Callable[[R], Awaitable[RRes]] | Type[Handler[R, RRes]]
+HandlerType = Union[Type[Handler[R, RRes]], Callable[..., Awaitable[RRes]]]
