@@ -1,3 +1,5 @@
+from collections.abc import Awaitable, Callable, Sequence
+import functools
 from typing import Any, TypeVar
 
 from didiator.interface.entities.request import Request
@@ -28,3 +30,16 @@ class Middleware:
             handler = handler()
 
         return await handler(request, *args, **kwargs)
+
+
+MiddlewareType = Callable[[HandlerType[R, RRes], R], Awaitable[RRes]]
+
+
+def wrap_middleware(
+    middlewares: Sequence[MiddlewareType[R, RRes]],
+    handler: HandlerType[R, RRes],
+) -> Callable[..., Awaitable[RRes]]:
+    for middleware in reversed(middlewares):
+        handler = functools.partial(middleware, handler)
+
+    return handler
